"""FortiOS CMDB - Ippool category"""

from ..ippool_base import Ippool as IppoolBase
from .mapping import Mapping

__all__ = [
    "Ippool",
    "Mapping",
]


class Ippool(IppoolBase):
    """Ippool endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Ippool endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        super().__init__(client)  # Initialize base class with GET methods
        self.mapping = Mapping(client)



"""
Pydantic Models for CMDB - wireless_controller/access_control_list

Runtime validation models for wireless_controller/access_control_list configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Literal, Optional

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class AccessControlListLayer3Ipv6Rules(BaseModel):
    """
    Child table model for layer3-ipv6-rules.
    
    AP ACL layer3 ipv6 rule list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    rule_id: int | None = Field(ge=1, le=65535, default=0, description="Rule ID (1 - 65535).")    
    comment: str | None = Field(max_length=63, default=None, description="Description.")    
    srcaddr: str | None = Field(default=None, description="Source IPv6 address (any | local-LAN | IPv6 address[/prefix length]), default = any.")    
    srcport: int | None = Field(ge=0, le=65535, default=0, description="Source port (0 - 65535, default = 0, meaning any).")    
    dstaddr: str | None = Field(default=None, description="Destination IPv6 address (any | local-LAN | IPv6 address[/prefix length]), default = any.")    
    dstport: int | None = Field(ge=0, le=65535, default=0, description="Destination port (0 - 65535, default = 0, meaning any).")    
    protocol: int | None = Field(ge=0, le=255, default=255, description="Protocol type as defined by IANA (0 - 255, default = 255, meaning any).")    
    action: Literal["allow", "deny"] | None = Field(default=None, description="Policy action (allow | deny).")
class AccessControlListLayer3Ipv4Rules(BaseModel):
    """
    Child table model for layer3-ipv4-rules.
    
    AP ACL layer3 ipv4 rule list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    rule_id: int | None = Field(ge=1, le=65535, default=0, description="Rule ID (1 - 65535).")    
    comment: str | None = Field(max_length=63, default=None, description="Description.")    
    srcaddr: str | None = Field(default=None, description="Source IP address (any | local-LAN | IPv4 address[/<network mask | mask length>], default = any).")    
    srcport: int | None = Field(ge=0, le=65535, default=0, description="Source port (0 - 65535, default = 0, meaning any).")    
    dstaddr: str | None = Field(default=None, description="Destination IP address (any | local-LAN | IPv4 address[/<network mask | mask length>], default = any).")    
    dstport: int | None = Field(ge=0, le=65535, default=0, description="Destination port (0 - 65535, default = 0, meaning any).")    
    protocol: int | None = Field(ge=0, le=255, default=255, description="Protocol type as defined by IANA (0 - 255, default = 255, meaning any).")    
    action: Literal["allow", "deny"] | None = Field(default=None, description="Policy action (allow | deny).")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================


# ============================================================================
# Main Model
# ============================================================================

class AccessControlListModel(BaseModel):
    """
    Pydantic model for wireless_controller/access_control_list configuration.
    
    Configure WiFi bridge access control list.
    
    Validation Rules:        - name: max_length=35 pattern=        - comment: max_length=63 pattern=        - layer3_ipv4_rules: pattern=        - layer3_ipv6_rules: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=35, default=None, description="AP access control list name.")    
    comment: str | None = Field(max_length=63, default=None, description="Description.")    
    layer3_ipv4_rules: list[AccessControlListLayer3Ipv4Rules] = Field(default_factory=list, description="AP ACL layer3 ipv4 rule list.")    
    layer3_ipv6_rules: list[AccessControlListLayer3Ipv6Rules] = Field(default_factory=list, description="AP ACL layer3 ipv6 rule list.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "AccessControlListModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "AccessControlListModel",    "AccessControlListLayer3Ipv4Rules",    "AccessControlListLayer3Ipv6Rules",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:00.772237Z
# ============================================================================


"""Type stubs for FIREWALL category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .DoS_policy import DosPolicy
    from .DoS_policy6 import DosPolicy6
    from .access_proxy import AccessProxy
    from .access_proxy6 import AccessProxy6
    from .access_proxy_ssh_client_cert import AccessProxySshClientCert
    from .access_proxy_virtual_host import AccessProxyVirtualHost
    from .address import Address
    from .address6 import Address6
    from .address6_template import Address6Template
    from .addrgrp import Addrgrp
    from .addrgrp6 import Addrgrp6
    from .auth_portal import AuthPortal
    from .central_snat_map import CentralSnatMap
    from .city import City
    from .country import Country
    from .decrypted_traffic_mirror import DecryptedTrafficMirror
    from .dnstranslation import Dnstranslation
    from .global_ import Global
    from .identity_based_route import IdentityBasedRoute
    from .interface_policy import InterfacePolicy
    from .interface_policy6 import InterfacePolicy6
    from .internet_service import InternetService
    from .internet_service_addition import InternetServiceAddition
    from .internet_service_append import InternetServiceAppend
    from .internet_service_botnet import InternetServiceBotnet
    from .internet_service_custom import InternetServiceCustom
    from .internet_service_custom_group import InternetServiceCustomGroup
    from .internet_service_definition import InternetServiceDefinition
    from .internet_service_extension import InternetServiceExtension
    from .internet_service_fortiguard import InternetServiceFortiguard
    from .internet_service_group import InternetServiceGroup
    from .internet_service_ipbl_reason import InternetServiceIpblReason
    from .internet_service_ipbl_vendor import InternetServiceIpblVendor
    from .internet_service_list import InternetServiceList
    from .internet_service_name import InternetServiceName
    from .internet_service_owner import InternetServiceOwner
    from .internet_service_reputation import InternetServiceReputation
    from .internet_service_sld import InternetServiceSld
    from .internet_service_subapp import InternetServiceSubapp
    from .ip_translation import IpTranslation
    from .ippool import Ippool
    from .ippool6 import Ippool6
    from .ldb_monitor import LdbMonitor
    from .local_in_policy import LocalInPolicy
    from .local_in_policy6 import LocalInPolicy6
    from .multicast_address import MulticastAddress
    from .multicast_address6 import MulticastAddress6
    from .multicast_policy import MulticastPolicy
    from .multicast_policy6 import MulticastPolicy6
    from .network_service_dynamic import NetworkServiceDynamic
    from .on_demand_sniffer import OnDemandSniffer
    from .policy import Policy
    from .profile_group import ProfileGroup
    from .profile_protocol_options import ProfileProtocolOptions
    from .proxy_address import ProxyAddress
    from .proxy_addrgrp import ProxyAddrgrp
    from .proxy_policy import ProxyPolicy
    from .region import Region
    from .security_policy import SecurityPolicy
    from .shaping_policy import ShapingPolicy
    from .shaping_profile import ShapingProfile
    from .sniffer import Sniffer
    from .ssl_server import SslServer
    from .ssl_ssh_profile import SslSshProfile
    from .traffic_class import TrafficClass
    from .ttl_policy import TtlPolicy
    from .vendor_mac import VendorMac
    from .vendor_mac_summary import VendorMacSummary
    from .vip import Vip
    from .vip6 import Vip6
    from .vipgrp import Vipgrp
    from .vipgrp6 import Vipgrp6
    from .ipmacbinding import Ipmacbinding
    from .schedule import Schedule
    from .service import Service
    from .shaper import Shaper
    from .ssh import Ssh
    from .ssl import Ssl
    from .wildcard_fqdn import WildcardFqdn

__all__ = [
    "DosPolicy",
    "DosPolicy6",
    "AccessProxy",
    "AccessProxy6",
    "AccessProxySshClientCert",
    "AccessProxyVirtualHost",
    "Address",
    "Address6",
    "Address6Template",
    "Addrgrp",
    "Addrgrp6",
    "AuthPortal",
    "CentralSnatMap",
    "City",
    "Country",
    "DecryptedTrafficMirror",
    "Dnstranslation",
    "Global",
    "IdentityBasedRoute",
    "InterfacePolicy",
    "InterfacePolicy6",
    "InternetService",
    "InternetServiceAddition",
    "InternetServiceAppend",
    "InternetServiceBotnet",
    "InternetServiceCustom",
    "InternetServiceCustomGroup",
    "InternetServiceDefinition",
    "InternetServiceExtension",
    "InternetServiceFortiguard",
    "InternetServiceGroup",
    "InternetServiceIpblReason",
    "InternetServiceIpblVendor",
    "InternetServiceList",
    "InternetServiceName",
    "InternetServiceOwner",
    "InternetServiceReputation",
    "InternetServiceSld",
    "InternetServiceSubapp",
    "IpTranslation",
    "Ippool",
    "Ippool6",
    "LdbMonitor",
    "LocalInPolicy",
    "LocalInPolicy6",
    "MulticastAddress",
    "MulticastAddress6",
    "MulticastPolicy",
    "MulticastPolicy6",
    "NetworkServiceDynamic",
    "OnDemandSniffer",
    "Policy",
    "ProfileGroup",
    "ProfileProtocolOptions",
    "ProxyAddress",
    "ProxyAddrgrp",
    "ProxyPolicy",
    "Region",
    "SecurityPolicy",
    "ShapingPolicy",
    "ShapingProfile",
    "Sniffer",
    "SslServer",
    "SslSshProfile",
    "TrafficClass",
    "TtlPolicy",
    "VendorMac",
    "VendorMacSummary",
    "Vip",
    "Vip6",
    "Vipgrp",
    "Vipgrp6",
    "Firewall",
]


class Firewall:
    """FIREWALL API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    ipmacbinding: Ipmacbinding
    schedule: Schedule
    service: Service
    shaper: Shaper
    ssh: Ssh
    ssl: Ssl
    wildcard_fqdn: WildcardFqdn
    DoS_policy: DosPolicy
    DoS_policy6: DosPolicy6
    access_proxy: AccessProxy
    access_proxy6: AccessProxy6
    access_proxy_ssh_client_cert: AccessProxySshClientCert
    access_proxy_virtual_host: AccessProxyVirtualHost
    address: Address
    address6: Address6
    address6_template: Address6Template
    addrgrp: Addrgrp
    addrgrp6: Addrgrp6
    auth_portal: AuthPortal
    central_snat_map: CentralSnatMap
    city: City
    country: Country
    decrypted_traffic_mirror: DecryptedTrafficMirror
    dnstranslation: Dnstranslation
    global_: Global
    identity_based_route: IdentityBasedRoute
    interface_policy: InterfacePolicy
    interface_policy6: InterfacePolicy6
    internet_service: InternetService
    internet_service_addition: InternetServiceAddition
    internet_service_append: InternetServiceAppend
    internet_service_botnet: InternetServiceBotnet
    internet_service_custom: InternetServiceCustom
    internet_service_custom_group: InternetServiceCustomGroup
    internet_service_definition: InternetServiceDefinition
    internet_service_extension: InternetServiceExtension
    internet_service_fortiguard: InternetServiceFortiguard
    internet_service_group: InternetServiceGroup
    internet_service_ipbl_reason: InternetServiceIpblReason
    internet_service_ipbl_vendor: InternetServiceIpblVendor
    internet_service_list: InternetServiceList
    internet_service_name: InternetServiceName
    internet_service_owner: InternetServiceOwner
    internet_service_reputation: InternetServiceReputation
    internet_service_sld: InternetServiceSld
    internet_service_subapp: InternetServiceSubapp
    ip_translation: IpTranslation
    ippool: Ippool
    ippool6: Ippool6
    ldb_monitor: LdbMonitor
    local_in_policy: LocalInPolicy
    local_in_policy6: LocalInPolicy6
    multicast_address: MulticastAddress
    multicast_address6: MulticastAddress6
    multicast_policy: MulticastPolicy
    multicast_policy6: MulticastPolicy6
    network_service_dynamic: NetworkServiceDynamic
    on_demand_sniffer: OnDemandSniffer
    policy: Policy
    profile_group: ProfileGroup
    profile_protocol_options: ProfileProtocolOptions
    proxy_address: ProxyAddress
    proxy_addrgrp: ProxyAddrgrp
    proxy_policy: ProxyPolicy
    region: Region
    security_policy: SecurityPolicy
    shaping_policy: ShapingPolicy
    shaping_profile: ShapingProfile
    sniffer: Sniffer
    ssl_server: SslServer
    ssl_ssh_profile: SslSshProfile
    traffic_class: TrafficClass
    ttl_policy: TtlPolicy
    vendor_mac: VendorMac
    vendor_mac_summary: VendorMacSummary
    vip: Vip
    vip6: Vip6
    vipgrp: Vipgrp
    vipgrp6: Vipgrp6

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize firewall category with HTTP client."""
        ...



"""
Pydantic Models for CMDB - user/pop3

Runtime validation models for user/pop3 configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class Pop3SslMinProtoVersionEnum(str, Enum):
    """Allowed values for ssl_min_proto_version field."""
    DEFAULT = "default"
    SSLV3 = "SSLv3"
    TLSV1 = "TLSv1"
    TLSV1_1 = "TLSv1-1"
    TLSV1_2 = "TLSv1-2"
    TLSV1_3 = "TLSv1-3"


# ============================================================================
# Main Model
# ============================================================================

class Pop3Model(BaseModel):
    """
    Pydantic model for user/pop3 configuration.
    
    POP3 server entry configuration.
    
    Validation Rules:        - name: max_length=35 pattern=        - server: max_length=63 pattern=        - port: min=0 max=65535 pattern=        - secure: pattern=        - ssl_min_proto_version: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=35, default=None, description="POP3 server entry name.")    
    server: str = Field(max_length=63, description="Server domain name or IP address.")    
    port: int | None = Field(ge=0, le=65535, default=0, description="POP3 service port number.")    
    secure: Literal["none", "starttls", "pop3s"] | None = Field(default="starttls", description="SSL connection.")    
    ssl_min_proto_version: Pop3SslMinProtoVersionEnum | None = Field(default=Pop3SslMinProtoVersionEnum.DEFAULT, description="Minimum supported protocol version for SSL/TLS connections (default is to follow system global setting).")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "Pop3Model":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "Pop3Model",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:02.302683Z
# ============================================================================


"""FortiOS CMDB - Dnat category (stub)"""

from typing import Any
from ..dnat_base import Dnat as DnatBase
from .clear_counters import ClearCounters
from .reset import Reset

class Dnat(DnatBase):
    """Dnat endpoints wrapper for CMDB API."""

    clear_counters: ClearCounters
    reset: Reset

    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...



"""
Pydantic Models for CMDB - wireless_controller/wtp

Runtime validation models for wireless_controller/wtp configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum
from uuid import UUID

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

class WtpRadio4BandEnum(str, Enum):
    """Allowed values for band field in radio-4."""
    V_802_11A = "802.11a"
    V_802_11B = "802.11b"
    V_802_11G = "802.11g"
    V_802_11N_2G = "802.11n-2G"
    V_802_11N_5G = "802.11n-5G"
    V_802_11AC_2G = "802.11ac-2G"
    V_802_11AC_5G = "802.11ac-5G"
    V_802_11AX_2G = "802.11ax-2G"
    V_802_11AX_5G = "802.11ax-5G"
    V_802_11AX_6G = "802.11ax-6G"
    V_802_11BE_2G = "802.11be-2G"
    V_802_11BE_5G = "802.11be-5G"
    V_802_11BE_6G = "802.11be-6G"

class WtpRadio4DrmaManualModeEnum(str, Enum):
    """Allowed values for drma_manual_mode field in radio-4."""
    AP = "ap"
    MONITOR = "monitor"
    NCF = "ncf"
    NCF_PEEK = "ncf-peek"

class WtpRadio3BandEnum(str, Enum):
    """Allowed values for band field in radio-3."""
    V_802_11A = "802.11a"
    V_802_11B = "802.11b"
    V_802_11G = "802.11g"
    V_802_11N_2G = "802.11n-2G"
    V_802_11N_5G = "802.11n-5G"
    V_802_11AC_2G = "802.11ac-2G"
    V_802_11AC_5G = "802.11ac-5G"
    V_802_11AX_2G = "802.11ax-2G"
    V_802_11AX_5G = "802.11ax-5G"
    V_802_11AX_6G = "802.11ax-6G"
    V_802_11BE_2G = "802.11be-2G"
    V_802_11BE_5G = "802.11be-5G"
    V_802_11BE_6G = "802.11be-6G"

class WtpRadio3DrmaManualModeEnum(str, Enum):
    """Allowed values for drma_manual_mode field in radio-3."""
    AP = "ap"
    MONITOR = "monitor"
    NCF = "ncf"
    NCF_PEEK = "ncf-peek"

class WtpRadio2BandEnum(str, Enum):
    """Allowed values for band field in radio-2."""
    V_802_11A = "802.11a"
    V_802_11B = "802.11b"
    V_802_11G = "802.11g"
    V_802_11N_2G = "802.11n-2G"
    V_802_11N_5G = "802.11n-5G"
    V_802_11AC_2G = "802.11ac-2G"
    V_802_11AC_5G = "802.11ac-5G"
    V_802_11AX_2G = "802.11ax-2G"
    V_802_11AX_5G = "802.11ax-5G"
    V_802_11AX_6G = "802.11ax-6G"
    V_802_11BE_2G = "802.11be-2G"
    V_802_11BE_5G = "802.11be-5G"
    V_802_11BE_6G = "802.11be-6G"

class WtpRadio2DrmaManualModeEnum(str, Enum):
    """Allowed values for drma_manual_mode field in radio-2."""
    AP = "ap"
    MONITOR = "monitor"
    NCF = "ncf"
    NCF_PEEK = "ncf-peek"

class WtpRadio1BandEnum(str, Enum):
    """Allowed values for band field in radio-1."""
    V_802_11A = "802.11a"
    V_802_11B = "802.11b"
    V_802_11G = "802.11g"
    V_802_11N_2G = "802.11n-2G"
    V_802_11N_5G = "802.11n-5G"
    V_802_11AC_2G = "802.11ac-2G"
    V_802_11AC_5G = "802.11ac-5G"
    V_802_11AX_2G = "802.11ax-2G"
    V_802_11AX_5G = "802.11ax-5G"
    V_802_11AX_6G = "802.11ax-6G"
    V_802_11BE_2G = "802.11be-2G"
    V_802_11BE_5G = "802.11be-5G"
    V_802_11BE_6G = "802.11be-6G"

class WtpRadio1DrmaManualModeEnum(str, Enum):
    """Allowed values for drma_manual_mode field in radio-1."""
    AP = "ap"
    MONITOR = "monitor"
    NCF = "ncf"
    NCF_PEEK = "ncf-peek"

class WtpLanPortModeEnum(str, Enum):
    """Allowed values for port_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort1ModeEnum(str, Enum):
    """Allowed values for port1_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort2ModeEnum(str, Enum):
    """Allowed values for port2_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort3ModeEnum(str, Enum):
    """Allowed values for port3_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort4ModeEnum(str, Enum):
    """Allowed values for port4_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort5ModeEnum(str, Enum):
    """Allowed values for port5_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort6ModeEnum(str, Enum):
    """Allowed values for port6_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort7ModeEnum(str, Enum):
    """Allowed values for port7_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPort8ModeEnum(str, Enum):
    """Allowed values for port8_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

class WtpLanPortEslModeEnum(str, Enum):
    """Allowed values for port_esl_mode field in lan."""
    OFFLINE = "offline"
    NAT_TO_WAN = "nat-to-wan"
    BRIDGE_TO_WAN = "bridge-to-wan"
    BRIDGE_TO_SSID = "bridge-to-ssid"

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class WtpSplitTunnelingAcl(BaseModel):
    """
    Child table model for split-tunneling-acl.
    
    Split tunneling ACL filter list.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int | None = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="ID.")    
    dest_ip: str = Field(default="0.0.0.0 0.0.0.0", description="Destination IP and mask for the split-tunneling subnet.")
class WtpRadio4Vaps(BaseModel):
    """
    Child table model for radio-4.vaps.
    
    Manually selected list of Virtual Access Points (VAPs).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=35, description="Virtual Access Point (VAP) name.")  # datasource: ['wireless-controller.vap-group.name', 'system.interface.name']
class WtpRadio4Channel(BaseModel):
    """
    Child table model for radio-4.channel.
    
    Selected list of wireless radio channels.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    chan: str = Field(max_length=3, description="Channel number.")
class WtpRadio4(BaseModel):
    """
    Child table model for radio-4.
    
    Configuration options for radio 4.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    override_band: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile band setting.")    
    band: list[WtpRadio4BandEnum] = Field(default_factory=list, description="WiFi band that Radio 4 operates on.")    
    override_txpower: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile power level configuration.")    
    auto_power_level: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable automatic power-level adjustment to prevent co-channel interference (default = enable).")    
    auto_power_high: int | None = Field(ge=0, le=4294967295, default=17, description="The upper bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_low: int | None = Field(ge=0, le=4294967295, default=10, description="The lower bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_target: str | None = Field(max_length=7, default="-70", description="Target of automatic transmit power adjustment in dBm (-95 to -20, default = -70).")    
    power_mode: Literal["dBm", "percentage"] | None = Field(default="percentage", description="Set radio effective isotropic radiated power (EIRP) in dBm or by a percentage of the maximum EIRP (default = percentage). This power takes into account both radio transmit power and antenna gain. Higher power level settings may be constrained by local regulatory requirements and AP capabilities.")    
    power_level: int | None = Field(ge=0, le=100, default=100, description="Radio EIRP power level as a percentage of the maximum EIRP power (0 - 100, default = 100).")    
    power_value: int | None = Field(ge=1, le=33, default=27, description="Radio EIRP power in dBm (1 - 33, default = 27).")    
    override_vaps: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile Virtual Access Point (VAP) settings.")    
    vap_all: Literal["tunnel", "bridge", "manual"] | None = Field(default="tunnel", description="Configure method for assigning SSIDs to this FortiAP (default = automatically assign tunnel SSIDs).")    
    vaps: list[WtpRadio4Vaps] = Field(default_factory=list, description="Manually selected list of Virtual Access Points (VAPs).")    
    override_channel: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile channel settings.")    
    channel: list[WtpRadio4Channel] = Field(default_factory=list, description="Selected list of wireless radio channels.")    
    drma_manual_mode: WtpRadio4DrmaManualModeEnum | None = Field(default=WtpRadio4DrmaManualModeEnum.NCF, description="Radio mode to be used for DRMA manual mode (default = ncf).")
class WtpRadio3Vaps(BaseModel):
    """
    Child table model for radio-3.vaps.
    
    Manually selected list of Virtual Access Points (VAPs).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=35, description="Virtual Access Point (VAP) name.")  # datasource: ['wireless-controller.vap-group.name', 'system.interface.name']
class WtpRadio3Channel(BaseModel):
    """
    Child table model for radio-3.channel.
    
    Selected list of wireless radio channels.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    chan: str = Field(max_length=3, description="Channel number.")
class WtpRadio3(BaseModel):
    """
    Child table model for radio-3.
    
    Configuration options for radio 3.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    override_band: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile band setting.")    
    band: list[WtpRadio3BandEnum] = Field(default_factory=list, description="WiFi band that Radio 3 operates on.")    
    override_txpower: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile power level configuration.")    
    auto_power_level: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable automatic power-level adjustment to prevent co-channel interference (default = enable).")    
    auto_power_high: int | None = Field(ge=0, le=4294967295, default=17, description="The upper bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_low: int | None = Field(ge=0, le=4294967295, default=10, description="The lower bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_target: str | None = Field(max_length=7, default="-70", description="Target of automatic transmit power adjustment in dBm (-95 to -20, default = -70).")    
    power_mode: Literal["dBm", "percentage"] | None = Field(default="percentage", description="Set radio effective isotropic radiated power (EIRP) in dBm or by a percentage of the maximum EIRP (default = percentage). This power takes into account both radio transmit power and antenna gain. Higher power level settings may be constrained by local regulatory requirements and AP capabilities.")    
    power_level: int | None = Field(ge=0, le=100, default=100, description="Radio EIRP power level as a percentage of the maximum EIRP power (0 - 100, default = 100).")    
    power_value: int | None = Field(ge=1, le=33, default=27, description="Radio EIRP power in dBm (1 - 33, default = 27).")    
    override_vaps: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile Virtual Access Point (VAP) settings.")    
    vap_all: Literal["tunnel", "bridge", "manual"] | None = Field(default="tunnel", description="Configure method for assigning SSIDs to this FortiAP (default = automatically assign tunnel SSIDs).")    
    vaps: list[WtpRadio3Vaps] = Field(default_factory=list, description="Manually selected list of Virtual Access Points (VAPs).")    
    override_channel: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile channel settings.")    
    channel: list[WtpRadio3Channel] = Field(default_factory=list, description="Selected list of wireless radio channels.")    
    drma_manual_mode: WtpRadio3DrmaManualModeEnum | None = Field(default=WtpRadio3DrmaManualModeEnum.NCF, description="Radio mode to be used for DRMA manual mode (default = ncf).")
class WtpRadio2Vaps(BaseModel):
    """
    Child table model for radio-2.vaps.
    
    Manually selected list of Virtual Access Points (VAPs).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=35, description="Virtual Access Point (VAP) name.")  # datasource: ['wireless-controller.vap-group.name', 'system.interface.name']
class WtpRadio2Channel(BaseModel):
    """
    Child table model for radio-2.channel.
    
    Selected list of wireless radio channels.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    chan: str = Field(max_length=3, description="Channel number.")
class WtpRadio2(BaseModel):
    """
    Child table model for radio-2.
    
    Configuration options for radio 2.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    override_band: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile band setting.")    
    band: list[WtpRadio2BandEnum] = Field(default_factory=list, description="WiFi band that Radio 2 operates on.")    
    override_txpower: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile power level configuration.")    
    auto_power_level: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable automatic power-level adjustment to prevent co-channel interference (default = enable).")    
    auto_power_high: int | None = Field(ge=0, le=4294967295, default=17, description="The upper bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_low: int | None = Field(ge=0, le=4294967295, default=10, description="The lower bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_target: str | None = Field(max_length=7, default="-70", description="Target of automatic transmit power adjustment in dBm (-95 to -20, default = -70).")    
    power_mode: Literal["dBm", "percentage"] | None = Field(default="percentage", description="Set radio effective isotropic radiated power (EIRP) in dBm or by a percentage of the maximum EIRP (default = percentage). This power takes into account both radio transmit power and antenna gain. Higher power level settings may be constrained by local regulatory requirements and AP capabilities.")    
    power_level: int | None = Field(ge=0, le=100, default=100, description="Radio EIRP power level as a percentage of the maximum EIRP power (0 - 100, default = 100).")    
    power_value: int | None = Field(ge=1, le=33, default=27, description="Radio EIRP power in dBm (1 - 33, default = 27).")    
    override_vaps: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile Virtual Access Point (VAP) settings.")    
    vap_all: Literal["tunnel", "bridge", "manual"] | None = Field(default="tunnel", description="Configure method for assigning SSIDs to this FortiAP (default = automatically assign tunnel SSIDs).")    
    vaps: list[WtpRadio2Vaps] = Field(default_factory=list, description="Manually selected list of Virtual Access Points (VAPs).")    
    override_channel: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile channel settings.")    
    channel: list[WtpRadio2Channel] = Field(default_factory=list, description="Selected list of wireless radio channels.")    
    drma_manual_mode: WtpRadio2DrmaManualModeEnum | None = Field(default=WtpRadio2DrmaManualModeEnum.NCF, description="Radio mode to be used for DRMA manual mode (default = ncf).")
class WtpRadio1Vaps(BaseModel):
    """
    Child table model for radio-1.vaps.
    
    Manually selected list of Virtual Access Points (VAPs).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=35, description="Virtual Access Point (VAP) name.")  # datasource: ['wireless-controller.vap-group.name', 'system.interface.name']
class WtpRadio1Channel(BaseModel):
    """
    Child table model for radio-1.channel.
    
    Selected list of wireless radio channels.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    chan: str = Field(max_length=3, description="Channel number.")
class WtpRadio1(BaseModel):
    """
    Child table model for radio-1.
    
    Configuration options for radio 1.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    override_band: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile band setting.")    
    band: list[WtpRadio1BandEnum] = Field(default_factory=list, description="WiFi band that Radio 1 operates on.")    
    override_txpower: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile power level configuration.")    
    auto_power_level: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable automatic power-level adjustment to prevent co-channel interference (default = enable).")    
    auto_power_high: int | None = Field(ge=0, le=4294967295, default=17, description="The upper bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_low: int | None = Field(ge=0, le=4294967295, default=10, description="The lower bound of automatic transmit power adjustment in dBm (the actual range of transmit power depends on the AP platform type).")    
    auto_power_target: str | None = Field(max_length=7, default="-70", description="Target of automatic transmit power adjustment in dBm (-95 to -20, default = -70).")    
    power_mode: Literal["dBm", "percentage"] | None = Field(default="percentage", description="Set radio effective isotropic radiated power (EIRP) in dBm or by a percentage of the maximum EIRP (default = percentage). This power takes into account both radio transmit power and antenna gain. Higher power level settings may be constrained by local regulatory requirements and AP capabilities.")    
    power_level: int | None = Field(ge=0, le=100, default=100, description="Radio EIRP power level as a percentage of the maximum EIRP power (0 - 100, default = 100).")    
    power_value: int | None = Field(ge=1, le=33, default=27, description="Radio EIRP power in dBm (1 - 33, default = 27).")    
    override_vaps: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile Virtual Access Point (VAP) settings.")    
    vap_all: Literal["tunnel", "bridge", "manual"] | None = Field(default="tunnel", description="Configure method for assigning SSIDs to this FortiAP (default = automatically assign tunnel SSIDs).")    
    vaps: list[WtpRadio1Vaps] = Field(default_factory=list, description="Manually selected list of Virtual Access Points (VAPs).")    
    override_channel: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override WTP profile channel settings.")    
    channel: list[WtpRadio1Channel] = Field(default_factory=list, description="Selected list of wireless radio channels.")    
    drma_manual_mode: WtpRadio1DrmaManualModeEnum | None = Field(default=WtpRadio1DrmaManualModeEnum.NCF, description="Radio mode to be used for DRMA manual mode (default = ncf).")
class WtpLan(BaseModel):
    """
    Child table model for lan.
    
    WTP LAN port mapping.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    port_mode: WtpLanPortModeEnum | None = Field(default=WtpLanPortModeEnum.OFFLINE, description="LAN port mode.")    
    port_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port to SSID.")  # datasource: ['system.interface.name']    
    port1_mode: WtpLanPort1ModeEnum | None = Field(default=WtpLanPort1ModeEnum.OFFLINE, description="LAN port 1 mode.")    
    port1_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 1 to SSID.")  # datasource: ['system.interface.name']    
    port2_mode: WtpLanPort2ModeEnum | None = Field(default=WtpLanPort2ModeEnum.OFFLINE, description="LAN port 2 mode.")    
    port2_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 2 to SSID.")  # datasource: ['system.interface.name']    
    port3_mode: WtpLanPort3ModeEnum | None = Field(default=WtpLanPort3ModeEnum.OFFLINE, description="LAN port 3 mode.")    
    port3_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 3 to SSID.")  # datasource: ['system.interface.name']    
    port4_mode: WtpLanPort4ModeEnum | None = Field(default=WtpLanPort4ModeEnum.OFFLINE, description="LAN port 4 mode.")    
    port4_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 4 to SSID.")  # datasource: ['system.interface.name']    
    port5_mode: WtpLanPort5ModeEnum | None = Field(default=WtpLanPort5ModeEnum.OFFLINE, description="LAN port 5 mode.")    
    port5_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 5 to SSID.")  # datasource: ['system.interface.name']    
    port6_mode: WtpLanPort6ModeEnum | None = Field(default=WtpLanPort6ModeEnum.OFFLINE, description="LAN port 6 mode.")    
    port6_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 6 to SSID.")  # datasource: ['system.interface.name']    
    port7_mode: WtpLanPort7ModeEnum | None = Field(default=WtpLanPort7ModeEnum.OFFLINE, description="LAN port 7 mode.")    
    port7_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 7 to SSID.")  # datasource: ['system.interface.name']    
    port8_mode: WtpLanPort8ModeEnum | None = Field(default=WtpLanPort8ModeEnum.OFFLINE, description="LAN port 8 mode.")    
    port8_ssid: str | None = Field(max_length=15, default=None, description="Bridge LAN port 8 to SSID.")  # datasource: ['system.interface.name']    
    port_esl_mode: WtpLanPortEslModeEnum | None = Field(default=WtpLanPortEslModeEnum.OFFLINE, description="ESL port mode.")    
    port_esl_ssid: str | None = Field(max_length=15, default=None, description="Bridge ESL port to SSID.")  # datasource: ['system.interface.name']
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class WtpPurdueLevelEnum(str, Enum):
    """Allowed values for purdue_level field."""
    V_1 = "1"
    V_1_5 = "1.5"
    V_2 = "2"
    V_2_5 = "2.5"
    V_3 = "3"
    V_3_5 = "3.5"
    V_4 = "4"
    V_5 = "5"
    V_5_5 = "5.5"


# ============================================================================
# Main Model
# ============================================================================

class WtpModel(BaseModel):
    """
    Pydantic model for wireless_controller/wtp configuration.
    
    Configure Wireless Termination Points (WTPs), that is, FortiAPs or APs to be managed by FortiGate.
    
    Validation Rules:        - wtp_id: max_length=35 pattern=        - index: min=0 max=4294967295 pattern=        - uuid: pattern=        - admin: pattern=        - name: max_length=35 pattern=        - location: max_length=35 pattern=        - comment: max_length=255 pattern=        - region: max_length=35 pattern=        - region_x: max_length=15 pattern=        - region_y: max_length=15 pattern=        - firmware_provision: max_length=35 pattern=        - firmware_provision_latest: pattern=        - wtp_profile: max_length=35 pattern=        - apcfg_profile: max_length=35 pattern=        - bonjour_profile: max_length=35 pattern=        - ble_major_id: min=0 max=65535 pattern=        - ble_minor_id: min=0 max=65535 pattern=        - override_led_state: pattern=        - led_state: pattern=        - override_wan_port_mode: pattern=        - wan_port_mode: pattern=        - override_ip_fragment: pattern=        - ip_fragment_preventing: pattern=        - tun_mtu_uplink: min=576 max=1500 pattern=        - tun_mtu_downlink: min=576 max=1500 pattern=        - override_split_tunnel: pattern=        - split_tunneling_acl_path: pattern=        - split_tunneling_acl_local_ap_subnet: pattern=        - split_tunneling_acl: pattern=        - override_lan: pattern=        - lan: pattern=        - override_allowaccess: pattern=        - allowaccess: pattern=        - override_login_passwd_change: pattern=        - login_passwd_change: pattern=        - login_passwd: max_length=128 pattern=        - override_default_mesh_root: pattern=        - default_mesh_root: pattern=        - radio_1: pattern=        - radio_2: pattern=        - radio_3: pattern=        - radio_4: pattern=        - image_download: pattern=        - mesh_bridge_enable: pattern=        - purdue_level: pattern=        - coordinate_latitude: max_length=19 pattern=        - coordinate_longitude: max_length=19 pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    wtp_id: str = Field(max_length=35, description="WTP ID.")    
    index: int | None = Field(ge=0, le=4294967295, default=0, description="Index (0 - 4294967295).")    
    uuid: str | None = Field(default="00000000-0000-0000-0000-000000000000", description="Universally Unique Identifier (UUID; automatically assigned but can be manually reset).")    
    admin: Literal["discovered", "disable", "enable"] | None = Field(default="enable", description="Configure how the FortiGate operating as a wireless controller discovers and manages this WTP, AP or FortiAP.")    
    name: str | None = Field(max_length=35, default=None, description="WTP, AP or FortiAP configuration name.")    
    location: str | None = Field(max_length=35, default=None, description="Field for describing the physical location of the WTP, AP or FortiAP.")    
    comment: str | None = Field(max_length=255, default=None, description="Comment.")    
    region: str | None = Field(max_length=35, default=None, description="Region name WTP is associated with.")  # datasource: ['wireless-controller.region.name']    
    region_x: str | None = Field(max_length=15, default="0", description="Relative horizontal region coordinate (between 0 and 1).")    
    region_y: str | None = Field(max_length=15, default="0", description="Relative vertical region coordinate (between 0 and 1).")    
    firmware_provision: str | None = Field(max_length=35, default=None, description="Firmware version to provision to this FortiAP on bootup (major.minor.build, i.e. 6.2.1234).")    
    firmware_provision_latest: Literal["disable", "once"] | None = Field(default="disable", description="Enable/disable one-time automatic provisioning of the latest firmware version.")    
    wtp_profile: str = Field(max_length=35, description="WTP profile name to apply to this WTP, AP or FortiAP.")  # datasource: ['wireless-controller.wtp-profile.name']    
    apcfg_profile: str | None = Field(max_length=35, default=None, description="AP local configuration profile name.")  # datasource: ['wireless-controller.apcfg-profile.name']    
    bonjour_profile: str | None = Field(max_length=35, default=None, description="Bonjour profile name.")  # datasource: ['wireless-controller.bonjour-profile.name']    
    ble_major_id: int | None = Field(ge=0, le=65535, default=0, description="Override BLE Major ID.")    
    ble_minor_id: int | None = Field(ge=0, le=65535, default=0, description="Override BLE Minor ID.")    
    override_led_state: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the profile LED state setting for this FortiAP. You must enable this option to use the led-state command to turn off the FortiAP's LEDs.")    
    led_state: Literal["enable", "disable"] | None = Field(default="enable", description="Enable to allow the FortiAPs LEDs to light. Disable to keep the LEDs off. You may want to keep the LEDs off so they are not distracting in low light areas etc.")    
    override_wan_port_mode: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable overriding the wan-port-mode in the WTP profile.")    
    wan_port_mode: Literal["wan-lan", "wan-only"] | None = Field(default="wan-only", description="Enable/disable using the FortiAP WAN port as a LAN port.")    
    override_ip_fragment: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable overriding the WTP profile IP fragment prevention setting.")    
    ip_fragment_preventing: list[Literal["tcp-mss-adjust", "icmp-unreachable"]] = Field(default_factory=list, description="Method(s) by which IP fragmentation is prevented for control and data packets through CAPWAP tunnel (default = tcp-mss-adjust).")    
    tun_mtu_uplink: int | None = Field(ge=576, le=1500, default=0, description="The maximum transmission unit (MTU) of uplink CAPWAP tunnel (576 - 1500 bytes or 0; 0 means the local MTU of FortiAP; default = 0).")    
    tun_mtu_downlink: int | None = Field(ge=576, le=1500, default=0, description="The MTU of downlink CAPWAP tunnel (576 - 1500 bytes or 0; 0 means the local MTU of FortiAP; default = 0).")    
    override_split_tunnel: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable overriding the WTP profile split tunneling setting.")    
    split_tunneling_acl_path: Literal["tunnel", "local"] | None = Field(default="local", description="Split tunneling ACL path is local/tunnel.")    
    split_tunneling_acl_local_ap_subnet: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable automatically adding local subnetwork of FortiAP to split-tunneling ACL (default = disable).")    
    split_tunneling_acl: list[WtpSplitTunnelingAcl] = Field(default_factory=list, description="Split tunneling ACL filter list.")    
    override_lan: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile LAN port setting.")    
    lan: WtpLan | None = Field(default=None, description="WTP LAN port mapping.")    
    override_allowaccess: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile management access configuration.")    
    allowaccess: list[Literal["https", "ssh", "snmp"]] = Field(default_factory=list, description="Control management access to the managed WTP, FortiAP, or AP. Separate entries with a space.")    
    override_login_passwd_change: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile login-password (administrator password) setting.")    
    login_passwd_change: Literal["yes", "default", "no"] | None = Field(default="no", description="Change or reset the administrator password of a managed WTP, FortiAP or AP (yes, default, or no, default = no).")    
    login_passwd: Any = Field(max_length=128, default=None, description="Set the managed WTP, FortiAP, or AP's administrator password.")    
    override_default_mesh_root: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to override the WTP profile default mesh root SSID setting.")    
    default_mesh_root: Literal["enable", "disable"] | None = Field(default="disable", description="Configure default mesh root SSID when it is not included by radio's SSID configuration.")    
    radio_1: WtpRadio1 | None = Field(default=None, description="Configuration options for radio 1.")    
    radio_2: WtpRadio2 | None = Field(default=None, description="Configuration options for radio 2.")    
    radio_3: WtpRadio3 | None = Field(default=None, description="Configuration options for radio 3.")    
    radio_4: WtpRadio4 | None = Field(default=None, description="Configuration options for radio 4.")    
    image_download: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable WTP image download.")    
    mesh_bridge_enable: Literal["default", "enable", "disable"] | None = Field(default="default", description="Enable/disable mesh Ethernet bridge when WTP is configured as a mesh branch/leaf AP.")    
    purdue_level: WtpPurdueLevelEnum | None = Field(default=WtpPurdueLevelEnum.V_3, description="Purdue Level of this WTP.")    
    coordinate_latitude: str | None = Field(max_length=19, default=None, description="WTP latitude coordinate.")    
    coordinate_longitude: str | None = Field(max_length=19, default=None, description="WTP longitude coordinate.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    @field_validator('region')
    @classmethod
    def validate_region(cls, v: Any) -> Any:
        """
        Validate region field.
        
        Datasource: ['wireless-controller.region.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('wtp_profile')
    @classmethod
    def validate_wtp_profile(cls, v: Any) -> Any:
        """
        Validate wtp_profile field.
        
        Datasource: ['wireless-controller.wtp-profile.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('apcfg_profile')
    @classmethod
    def validate_apcfg_profile(cls, v: Any) -> Any:
        """
        Validate apcfg_profile field.
        
        Datasource: ['wireless-controller.apcfg-profile.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('bonjour_profile')
    @classmethod
    def validate_bonjour_profile(cls, v: Any) -> Any:
        """
        Validate bonjour_profile field.
        
        Datasource: ['wireless-controller.bonjour-profile.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "WtpModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)
    # ========================================================================
    # Datasource Validation Methods
    # ========================================================================    
    async def validate_region_references(self, client: Any) -> list[str]:
        """
        Validate region references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/region        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = WtpModel(
            ...     region="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_region_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.wtp.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "region", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.region.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Region '{value}' not found in "
                "wireless-controller/region"
            )        
        return errors    
    async def validate_wtp_profile_references(self, client: Any) -> list[str]:
        """
        Validate wtp_profile references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/wtp-profile        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = WtpModel(
            ...     wtp_profile="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_wtp_profile_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.wtp.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "wtp_profile", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.wtp_profile.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Wtp-Profile '{value}' not found in "
                "wireless-controller/wtp-profile"
            )        
        return errors    
    async def validate_apcfg_profile_references(self, client: Any) -> list[str]:
        """
        Validate apcfg_profile references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/apcfg-profile        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = WtpModel(
            ...     apcfg_profile="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_apcfg_profile_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.wtp.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "apcfg_profile", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.apcfg_profile.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Apcfg-Profile '{value}' not found in "
                "wireless-controller/apcfg-profile"
            )        
        return errors    
    async def validate_bonjour_profile_references(self, client: Any) -> list[str]:
        """
        Validate bonjour_profile references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/bonjour-profile        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = WtpModel(
            ...     bonjour_profile="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_bonjour_profile_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.wtp.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "bonjour_profile", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.bonjour_profile.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Bonjour-Profile '{value}' not found in "
                "wireless-controller/bonjour-profile"
            )        
        return errors    
    async def validate_lan_references(self, client: Any) -> list[str]:
        """
        Validate lan references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - system/interface        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = WtpModel(
            ...     lan=[{"port-esl-ssid": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_lan_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.wtp.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "lan", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("port-esl-ssid")
            else:
                value = getattr(item, "port-esl-ssid", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.system.interface.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Lan '{value}' not found in "
                    "system/interface"
                )        
        return errors    
    async def validate_all_references(self, client: Any) -> list[str]:
        """
        Validate ALL datasource references in this model.
        
        Convenience method that runs all validate_*_references() methods
        and aggregates the results.
        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of all validation errors found
            
        Example:
            >>> errors = await policy.validate_all_references(fgt._client)
            >>> if errors:
            ...     for error in errors:
            ...         print(f"  - {error}")
        """
        all_errors = []
        
        errors = await self.validate_region_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_wtp_profile_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_apcfg_profile_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_bonjour_profile_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_lan_references(client)
        all_errors.extend(errors)        
        return all_errors

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "WtpModel",    "WtpSplitTunnelingAcl",    "WtpLan",    "WtpRadio1",    "WtpRadio1.Vaps",    "WtpRadio1.Channel",    "WtpRadio2",    "WtpRadio2.Vaps",    "WtpRadio2.Channel",    "WtpRadio3",    "WtpRadio3.Vaps",    "WtpRadio3.Channel",    "WtpRadio4",    "WtpRadio4.Vaps",    "WtpRadio4.Channel",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:00.259049Z
# ============================================================================


"""Type stubs for CERTIFICATE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .ca import Ca
    from .crl import Crl
    from .hsm_local import HsmLocal
    from .local import Local
    from .ocsp_server import OcspServer
    from .remote import Remote
    from .setting import Setting

__all__ = [
    "Ca",
    "Crl",
    "HsmLocal",
    "Local",
    "OcspServer",
    "Remote",
    "Setting",
    "Certificate",
]


class Certificate:
    """CERTIFICATE API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    ca: Ca
    crl: Crl
    hsm_local: HsmLocal
    local: Local
    ocsp_server: OcspServer
    remote: Remote
    setting: Setting

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize certificate category with HTTP client."""
        ...



"""Type stubs for RULE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .fmwp import Fmwp
    from .iotd import Iotd
    from .otdt import Otdt
    from .otvp import Otvp

__all__ = [
    "Fmwp",
    "Iotd",
    "Otdt",
    "Otvp",
    "Rule",
]


class Rule:
    """RULE API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    fmwp: Fmwp
    iotd: Iotd
    otdt: Otdt
    otvp: Otvp

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize rule category with HTTP client."""
        ...



from typing import Any, Literal

# Enum type aliases for validation
VALID_BODY_OVERRIDE_SYNC: Literal["enable", "disable"]

# Metadata dictionaries
FIELD_TYPES: dict[str, str]
FIELD_DESCRIPTIONS: dict[str, str]
FIELD_CONSTRAINTS: dict[str, dict[str, Any]]
NESTED_SCHEMAS: dict[str, dict[str, Any]]
FIELDS_WITH_DEFAULTS: dict[str, Any]
DEPRECATED_FIELDS: dict[str, dict[str, str]]
REQUIRED_FIELDS: list[str]

# Helper functions
def get_field_type(field_name: str) -> str | None: ...
def get_field_description(field_name: str) -> str | None: ...
def get_field_default(field_name: str) -> Any: ...
def get_field_constraints(field_name: str) -> dict[str, Any]: ...
def get_nested_schema(field_name: str) -> dict[str, Any] | None: ...
def get_field_metadata(field_name: str) -> dict[str, Any]: ...
def validate_field_value(field_name: str, value: Any) -> bool: ...
def get_all_fields() -> list[str]: ...
def get_required_fields() -> list[str]: ...
def get_schema_info() -> dict[str, Any]: ...


__all__ = [
    "VALID_BODY_OVERRIDE_SYNC",
    "FIELD_TYPES",
    "FIELD_DESCRIPTIONS",
    "FIELD_CONSTRAINTS",
    "NESTED_SCHEMAS",
    "FIELDS_WITH_DEFAULTS",
    "DEPRECATED_FIELDS",
    "REQUIRED_FIELDS",
    "get_field_type",
    "get_field_description",
    "get_field_default",
    "get_field_constraints",
    "get_nested_schema",
    "get_field_metadata",
    "validate_field_value",
    "get_all_fields",
    "get_required_fields",
    "get_schema_info",
]


"""FortiOS CMDB - Dhcp category (stub)"""

from typing import Any
from ..dhcp_base import Dhcp as DhcpBase
from .revoke import Revoke

class Dhcp(DhcpBase):
    """Dhcp endpoints wrapper for CMDB API."""

    revoke: Revoke

    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...



"""Type stubs for SERVICE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .category import Category
    from .custom import Custom
    from .group import Group

__all__ = [
    "Category",
    "Custom",
    "Group",
    "Service",
]


class Service:
    """SERVICE API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    category: Category
    custom: Custom
    group: Group

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize service category with HTTP client."""
        ...



"""Type stubs for SYSTEM category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .acme_certificate_status import AcmeCertificateStatus
    from .acquired_dns import AcquiredDns
    from .available_certificates import AvailableCertificates
    from .check_port_availability import CheckPortAvailability
    from .current_admins import CurrentAdmins
    from .global_resources import GlobalResources
    from .global_search import GlobalSearch
    from .ha_backup_hb_used import HaBackupHbUsed
    from .ha_checksums import HaChecksums
    from .ha_history import HaHistory
    from .ha_hw_interface import HaHwInterface
    from .ha_nonsync_checksums import HaNonsyncChecksums
    from .ha_statistics import HaStatistics
    from .ha_table_checksums import HaTableChecksums
    from .interface_connected_admins_info import InterfaceConnectedAdminsInfo
    from .ipconf import Ipconf
    from .link_monitor import LinkMonitor
    from .modem3g import Modem3g
    from .monitor_sensor import MonitorSensor
    from .resolve_fqdn import ResolveFqdn
    from .running_processes import RunningProcesses
    from .sensor_info import SensorInfo
    from .status import Status
    from .storage import Storage
    from .timezone import Timezone
    from .trusted_cert_authorities import TrustedCertAuthorities
    from .vdom_link import VdomLink
    from .vdom_resource import VdomResource
    from .vm_information import VmInformation
    from .admin import Admin
    from .api_user import ApiUser
    from .automation_action import AutomationAction
    from .automation_stitch import AutomationStitch
    from .available_interfaces import AvailableInterfaces
    from .botnet import Botnet
    from .botnet_domains import BotnetDomains
    from .central_management import CentralManagement
    from .certificate import Certificate
    from .change_password import ChangePassword
    from .cluster import Cluster
    from .com_log import ComLog
    from .config import Config
    from .config_error_log import ConfigErrorLog
    from .config_revision import ConfigRevision
    from .config_script import ConfigScript
    from .config_sync import ConfigSync
    from .crash_log import CrashLog
    from .csf import Csf
    from .debug import Debug
    from .dhcp import Dhcp
    from .dhcp6 import Dhcp6
    from .disconnect_admins import DisconnectAdmins
    from .external_resource import ExternalResource
    from .firmware import Firmware
    from .fortiguard import Fortiguard
    from .fortimanager import Fortimanager
    from .fsck import Fsck
    from .ha_peer import HaPeer
    from .hscalefw_license import HscalefwLicense
    from .interface import Interface
    from .ipam import Ipam
    from .logdisk import Logdisk
    from .lte_modem import LteModem
    from .modem import Modem
    from .modem5g import Modem5g
    from .ntp import Ntp
    from .object import Object
    from .os import Os
    from .password_policy_conform import PasswordPolicyConform
    from .performance import Performance
    from .private_data_encryption import PrivateDataEncryption
    from .process import Process
    from .resource import Resource
    from .sandbox import Sandbox
    from .sdn_connector import SdnConnector
    from .time import Time
    from .traffic_history import TrafficHistory
    from .upgrade_report import UpgradeReport
    from .usb_device import UsbDevice
    from .usb_log import UsbLog
    from .vmlicense import Vmlicense

__all__ = [
    "AcmeCertificateStatus",
    "AcquiredDns",
    "AvailableCertificates",
    "CheckPortAvailability",
    "CurrentAdmins",
    "GlobalResources",
    "GlobalSearch",
    "HaBackupHbUsed",
    "HaChecksums",
    "HaHistory",
    "HaHwInterface",
    "HaNonsyncChecksums",
    "HaStatistics",
    "HaTableChecksums",
    "InterfaceConnectedAdminsInfo",
    "Ipconf",
    "LinkMonitor",
    "Modem3g",
    "MonitorSensor",
    "ResolveFqdn",
    "RunningProcesses",
    "SensorInfo",
    "Status",
    "Storage",
    "Timezone",
    "TrustedCertAuthorities",
    "VdomLink",
    "VdomResource",
    "VmInformation",
    "System",
]


class System:
    """SYSTEM API category.
    
    All endpoints return FortiObject instances with:
    - Attribute access: response.field
    - Dictionary access: response["field"]
    - Convert to dict: response.dict or response.json
    """
    
    admin: Admin
    api_user: ApiUser
    automation_action: AutomationAction
    automation_stitch: AutomationStitch
    available_interfaces: AvailableInterfaces
    botnet: Botnet
    botnet_domains: BotnetDomains
    central_management: CentralManagement
    certificate: Certificate
    change_password: ChangePassword
    cluster: Cluster
    com_log: ComLog
    config: Config
    config_error_log: ConfigErrorLog
    config_revision: ConfigRevision
    config_script: ConfigScript
    config_sync: ConfigSync
    crash_log: CrashLog
    csf: Csf
    debug: Debug
    dhcp: Dhcp
    dhcp6: Dhcp6
    disconnect_admins: DisconnectAdmins
    external_resource: ExternalResource
    firmware: Firmware
    fortiguard: Fortiguard
    fortimanager: Fortimanager
    fsck: Fsck
    ha_peer: HaPeer
    hscalefw_license: HscalefwLicense
    interface: Interface
    ipam: Ipam
    logdisk: Logdisk
    lte_modem: LteModem
    modem: Modem
    modem5g: Modem5g
    ntp: Ntp
    object: Object
    os: Os
    password_policy_conform: PasswordPolicyConform
    performance: Performance
    private_data_encryption: PrivateDataEncryption
    process: Process
    resource: Resource
    sandbox: Sandbox
    sdn_connector: SdnConnector
    time: Time
    traffic_history: TrafficHistory
    upgrade_report: UpgradeReport
    usb_device: UsbDevice
    usb_log: UsbLog
    vmlicense: Vmlicense
    acme_certificate_status: AcmeCertificateStatus
    acquired_dns: AcquiredDns
    available_certificates: AvailableCertificates
    check_port_availability: CheckPortAvailability
    current_admins: CurrentAdmins
    global_resources: GlobalResources
    global_search: GlobalSearch
    ha_backup_hb_used: HaBackupHbUsed
    ha_checksums: HaChecksums
    ha_history: HaHistory
    ha_hw_interface: HaHwInterface
    ha_nonsync_checksums: HaNonsyncChecksums
    ha_statistics: HaStatistics
    ha_table_checksums: HaTableChecksums
    interface_connected_admins_info: InterfaceConnectedAdminsInfo
    ipconf: Ipconf
    link_monitor: LinkMonitor
    modem3g: Modem3g
    monitor_sensor: MonitorSensor
    resolve_fqdn: ResolveFqdn
    running_processes: RunningProcesses
    sensor_info: SensorInfo
    status: Status
    storage: Storage
    timezone: Timezone
    trusted_cert_authorities: TrustedCertAuthorities
    vdom_link: VdomLink
    vdom_resource: VdomResource
    vm_information: VmInformation

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize system category with HTTP client."""
        ...



"""
Pydantic Models for CMDB - firewall/vip6

Runtime validation models for firewall/vip6 configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum
from uuid import UUID

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

class Vip6SslServerCipherSuitesCipherEnum(str, Enum):
    """Allowed values for cipher field in ssl-server-cipher-suites."""
    TLS_AES_128_GCM_SHA256 = "TLS-AES-128-GCM-SHA256"
    TLS_AES_256_GCM_SHA384 = "TLS-AES-256-GCM-SHA384"
    TLS_CHACHA20_POLY1305_SHA256 = "TLS-CHACHA20-POLY1305-SHA256"
    TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA = "TLS-DHE-RSA-WITH-AES-128-CBC-SHA"
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA = "TLS-DHE-RSA-WITH-AES-256-CBC-SHA"
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_AES_128_GCM_SHA256 = "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256"
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA256 = "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_AES_256_GCM_SHA384 = "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384"
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA = "TLS-DHE-DSS-WITH-AES-128-CBC-SHA"
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA = "TLS-DHE-DSS-WITH-AES-256-CBC-SHA"
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_AES_128_GCM_SHA256 = "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256"
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA256 = "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256"
    TLS_DHE_DSS_WITH_AES_256_GCM_SHA384 = "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384"
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA = "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA"
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256 = "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256"
    TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256 = "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256"
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA = "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA"
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384 = "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384 = "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384"
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA = "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA"
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256 = "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256"
    TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256 = "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256"
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA = "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384 = "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384"
    TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384 = "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384"
    TLS_RSA_WITH_AES_128_CBC_SHA = "TLS-RSA-WITH-AES-128-CBC-SHA"
    TLS_RSA_WITH_AES_256_CBC_SHA = "TLS-RSA-WITH-AES-256-CBC-SHA"
    TLS_RSA_WITH_AES_128_CBC_SHA256 = "TLS-RSA-WITH-AES-128-CBC-SHA256"
    TLS_RSA_WITH_AES_128_GCM_SHA256 = "TLS-RSA-WITH-AES-128-GCM-SHA256"
    TLS_RSA_WITH_AES_256_CBC_SHA256 = "TLS-RSA-WITH-AES-256-CBC-SHA256"
    TLS_RSA_WITH_AES_256_GCM_SHA384 = "TLS-RSA-WITH-AES-256-GCM-SHA384"
    TLS_RSA_WITH_CAMELLIA_128_CBC_SHA = "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA"
    TLS_RSA_WITH_CAMELLIA_256_CBC_SHA = "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA"
    TLS_RSA_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_RSA_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA = "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA"
    TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA = "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA = "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA"
    TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA = "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_SEED_CBC_SHA = "TLS-DHE-RSA-WITH-SEED-CBC-SHA"
    TLS_DHE_DSS_WITH_SEED_CBC_SHA = "TLS-DHE-DSS-WITH-SEED-CBC-SHA"
    TLS_DHE_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_DHE_DSS_WITH_ARIA_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_ARIA_256_CBC_SHA384 = "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384"
    TLS_RSA_WITH_SEED_CBC_SHA = "TLS-RSA-WITH-SEED-CBC-SHA"
    TLS_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_ECDHE_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_ECDSA_WITH_ARIA_128_CBC_SHA256 = "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256"
    TLS_ECDHE_ECDSA_WITH_ARIA_256_CBC_SHA384 = "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_RC4_128_SHA = "TLS-ECDHE-RSA-WITH-RC4-128-SHA"
    TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA = "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA"
    TLS_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_RSA_WITH_RC4_128_MD5 = "TLS-RSA-WITH-RC4-128-MD5"
    TLS_RSA_WITH_RC4_128_SHA = "TLS-RSA-WITH-RC4-128-SHA"
    TLS_DHE_RSA_WITH_DES_CBC_SHA = "TLS-DHE-RSA-WITH-DES-CBC-SHA"
    TLS_DHE_DSS_WITH_DES_CBC_SHA = "TLS-DHE-DSS-WITH-DES-CBC-SHA"
    TLS_RSA_WITH_DES_CBC_SHA = "TLS-RSA-WITH-DES-CBC-SHA"

class Vip6SslServerCipherSuitesVersionsEnum(str, Enum):
    """Allowed values for versions field in ssl-server-cipher-suites."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"

class Vip6SslCipherSuitesCipherEnum(str, Enum):
    """Allowed values for cipher field in ssl-cipher-suites."""
    TLS_AES_128_GCM_SHA256 = "TLS-AES-128-GCM-SHA256"
    TLS_AES_256_GCM_SHA384 = "TLS-AES-256-GCM-SHA384"
    TLS_CHACHA20_POLY1305_SHA256 = "TLS-CHACHA20-POLY1305-SHA256"
    TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256 = "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256"
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA = "TLS-DHE-RSA-WITH-AES-128-CBC-SHA"
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA = "TLS-DHE-RSA-WITH-AES-256-CBC-SHA"
    TLS_DHE_RSA_WITH_AES_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_AES_128_GCM_SHA256 = "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256"
    TLS_DHE_RSA_WITH_AES_256_CBC_SHA256 = "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_AES_256_GCM_SHA384 = "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384"
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA = "TLS-DHE-DSS-WITH-AES-128-CBC-SHA"
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA = "TLS-DHE-DSS-WITH-AES-256-CBC-SHA"
    TLS_DHE_DSS_WITH_AES_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_AES_128_GCM_SHA256 = "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256"
    TLS_DHE_DSS_WITH_AES_256_CBC_SHA256 = "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256"
    TLS_DHE_DSS_WITH_AES_256_GCM_SHA384 = "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384"
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA = "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA"
    TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256 = "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256"
    TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256 = "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256"
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA = "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA"
    TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384 = "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384 = "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384"
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA = "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA"
    TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256 = "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256"
    TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256 = "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256"
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA = "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
    TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384 = "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384"
    TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384 = "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384"
    TLS_RSA_WITH_AES_128_CBC_SHA = "TLS-RSA-WITH-AES-128-CBC-SHA"
    TLS_RSA_WITH_AES_256_CBC_SHA = "TLS-RSA-WITH-AES-256-CBC-SHA"
    TLS_RSA_WITH_AES_128_CBC_SHA256 = "TLS-RSA-WITH-AES-128-CBC-SHA256"
    TLS_RSA_WITH_AES_128_GCM_SHA256 = "TLS-RSA-WITH-AES-128-GCM-SHA256"
    TLS_RSA_WITH_AES_256_CBC_SHA256 = "TLS-RSA-WITH-AES-256-CBC-SHA256"
    TLS_RSA_WITH_AES_256_GCM_SHA384 = "TLS-RSA-WITH-AES-256-GCM-SHA384"
    TLS_RSA_WITH_CAMELLIA_128_CBC_SHA = "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA"
    TLS_RSA_WITH_CAMELLIA_256_CBC_SHA = "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA"
    TLS_RSA_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_RSA_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA = "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA"
    TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA = "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA = "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA"
    TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA = "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA"
    TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA256 = "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256"
    TLS_DHE_RSA_WITH_SEED_CBC_SHA = "TLS-DHE-RSA-WITH-SEED-CBC-SHA"
    TLS_DHE_DSS_WITH_SEED_CBC_SHA = "TLS-DHE-DSS-WITH-SEED-CBC-SHA"
    TLS_DHE_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_DHE_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_DHE_DSS_WITH_ARIA_128_CBC_SHA256 = "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256"
    TLS_DHE_DSS_WITH_ARIA_256_CBC_SHA384 = "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384"
    TLS_RSA_WITH_SEED_CBC_SHA = "TLS-RSA-WITH-SEED-CBC-SHA"
    TLS_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_ARIA_128_CBC_SHA256 = "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256"
    TLS_ECDHE_RSA_WITH_ARIA_256_CBC_SHA384 = "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_ECDSA_WITH_ARIA_128_CBC_SHA256 = "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256"
    TLS_ECDHE_ECDSA_WITH_ARIA_256_CBC_SHA384 = "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384"
    TLS_ECDHE_RSA_WITH_RC4_128_SHA = "TLS-ECDHE-RSA-WITH-RC4-128-SHA"
    TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA = "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA"
    TLS_RSA_WITH_3DES_EDE_CBC_SHA = "TLS-RSA-WITH-3DES-EDE-CBC-SHA"
    TLS_RSA_WITH_RC4_128_MD5 = "TLS-RSA-WITH-RC4-128-MD5"
    TLS_RSA_WITH_RC4_128_SHA = "TLS-RSA-WITH-RC4-128-SHA"
    TLS_DHE_RSA_WITH_DES_CBC_SHA = "TLS-DHE-RSA-WITH-DES-CBC-SHA"
    TLS_DHE_DSS_WITH_DES_CBC_SHA = "TLS-DHE-DSS-WITH-DES-CBC-SHA"
    TLS_RSA_WITH_DES_CBC_SHA = "TLS-RSA-WITH-DES-CBC-SHA"

class Vip6SslCipherSuitesVersionsEnum(str, Enum):
    """Allowed values for versions field in ssl-cipher-suites."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class Vip6SslServerCipherSuites(BaseModel):
    """
    Child table model for ssl-server-cipher-suites.
    
    SSL/TLS cipher suites to offer to a server, ordered by priority.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    priority: int | None = Field(ge=0, le=4294967295, default=0, description="SSL/TLS cipher suites priority.")    
    cipher: Vip6SslServerCipherSuitesCipherEnum = Field(description="Cipher suite name.")    
    versions: list[Vip6SslServerCipherSuitesVersionsEnum] = Field(default_factory=list, description="SSL/TLS versions that the cipher suite can be used with.")
class Vip6SslCipherSuites(BaseModel):
    """
    Child table model for ssl-cipher-suites.
    
    SSL/TLS cipher suites acceptable from a client, ordered by priority.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    priority: int | None = Field(ge=0, le=4294967295, default=0, description="SSL/TLS cipher suites priority.")    
    cipher: Vip6SslCipherSuitesCipherEnum = Field(description="Cipher suite name.")    
    versions: list[Vip6SslCipherSuitesVersionsEnum] = Field(default_factory=list, description="SSL/TLS versions that the cipher suite can be used with.")
class Vip6SslCertificate(BaseModel):
    """
    Child table model for ssl-certificate.
    
    Name of the certificate to use for SSL handshake.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str | None = Field(max_length=79, default=None, description="Certificate list.")  # datasource: ['vpn.certificate.local.name']
class Vip6SrcFilter(BaseModel):
    """
    Child table model for src-filter.
    
    Source IP6 filter (x:x:x:x:x:x:x:x/x). Separate addresses with spaces.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    range_: str = Field(max_length=79, serialization_alias="range", description="Source-filter range.")
class Vip6RealserversMonitor(BaseModel):
    """
    Child table model for realservers.monitor.
    
    Name of the health check monitor to use when polling to determine a virtual server's connectivity status.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=79, description="Health monitor name.")  # datasource: ['firewall.ldb-monitor.name']
class Vip6Realservers(BaseModel):
    """
    Child table model for realservers.
    
    Select the real servers that this server load balancing VIP will distribute traffic to.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int | None = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Real server ID.")    
    ip: str = Field(description="IP address of the real server.")    
    port: int | None = Field(ge=1, le=65535, default=0, description="Port for communicating with the real server. Required if port forwarding is enabled.")    
    status: Literal["active", "standby", "disable"] | None = Field(default="active", description="Set the status of the real server to active so that it can accept traffic, or on standby or disabled so no traffic is sent.")    
    weight: int | None = Field(ge=1, le=255, default=1, description="Weight of the real server. If weighted load balancing is enabled, the server with the highest weight gets more connections.")    
    holddown_interval: int | None = Field(ge=30, le=65535, default=300, description="Time in seconds that the system waits before re-activating a previously down active server in the active-standby mode. This is to prevent any flapping issues.")    
    healthcheck: Literal["disable", "enable", "vip"] | None = Field(default="vip", description="Enable to check the responsiveness of the real server before forwarding traffic.")    
    http_host: str | None = Field(max_length=63, default=None, description="HTTP server domain name in HTTP header.")    
    translate_host: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable translation of hostname/IP from virtual server to real server.")    
    max_connections: int | None = Field(ge=0, le=2147483647, default=0, description="Max number of active connections that can directed to the real server. When reached, sessions are sent to other real servers.")    
    monitor: list[Vip6RealserversMonitor] = Field(default_factory=list, description="Name of the health check monitor to use when polling to determine a virtual server's connectivity status.")    
    client_ip: str | None = Field(default=None, description="Only clients in this IP range can connect to this real server.")    
    verify_cert: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable certificate verification of the real server.")
class Vip6Quic(BaseModel):
    """
    Child table model for quic.
    
    QUIC setting.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    max_idle_timeout: int | None = Field(ge=1, le=60000, default=30000, description="Maximum idle timeout milliseconds (1 - 60000, default = 30000).")    
    max_udp_payload_size: int | None = Field(ge=1200, le=1500, default=1500, description="Maximum UDP payload size in bytes (1200 - 1500, default = 1500).")    
    active_connection_id_limit: int | None = Field(ge=1, le=8, default=2, description="Active connection ID limit (1 - 8, default = 2).")    
    ack_delay_exponent: int | None = Field(ge=1, le=20, default=3, description="ACK delay exponent (1 - 20, default = 3).")    
    max_ack_delay: int | None = Field(ge=1, le=16383, default=25, description="Maximum ACK delay in milliseconds (1 - 16383, default = 25).")    
    max_datagram_frame_size: int | None = Field(ge=1, le=1500, default=1500, description="Maximum datagram frame size in bytes (1 - 1500, default = 1500).")    
    active_migration: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable active migration (default = disable).")    
    grease_quic_bit: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable grease QUIC bit (default = enable).")
class Vip6Monitor(BaseModel):
    """
    Child table model for monitor.
    
    Name of the health check monitor to use when polling to determine a virtual server's connectivity status.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=79, description="Health monitor name.")  # datasource: ['firewall.ldb-monitor.name']
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class Vip6LdbMethodEnum(str, Enum):
    """Allowed values for ldb_method field."""
    STATIC = "static"
    ROUND_ROBIN = "round-robin"
    WEIGHTED = "weighted"
    LEAST_SESSION = "least-session"
    LEAST_RTT = "least-rtt"
    FIRST_ALIVE = "first-alive"
    HTTP_HOST = "http-host"

class Vip6ServerTypeEnum(str, Enum):
    """Allowed values for server_type field."""
    HTTP = "http"
    HTTPS = "https"
    IMAPS = "imaps"
    POP3S = "pop3s"
    SMTPS = "smtps"
    SSL = "ssl"
    TCP = "tcp"
    UDP = "udp"
    IP = "ip"

class Vip6SslDhBitsEnum(str, Enum):
    """Allowed values for ssl_dh_bits field."""
    V_768 = "768"
    V_1024 = "1024"
    V_1536 = "1536"
    V_2048 = "2048"
    V_3072 = "3072"
    V_4096 = "4096"

class Vip6SslAlgorithmEnum(str, Enum):
    """Allowed values for ssl_algorithm field."""
    HIGH = "high"
    MEDIUM = "medium"
    LOW = "low"
    CUSTOM = "custom"

class Vip6SslServerAlgorithmEnum(str, Enum):
    """Allowed values for ssl_server_algorithm field."""
    HIGH = "high"
    MEDIUM = "medium"
    LOW = "low"
    CUSTOM = "custom"
    CLIENT = "client"

class Vip6SslMinVersionEnum(str, Enum):
    """Allowed values for ssl_min_version field."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"

class Vip6SslMaxVersionEnum(str, Enum):
    """Allowed values for ssl_max_version field."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"

class Vip6SslServerMinVersionEnum(str, Enum):
    """Allowed values for ssl_server_min_version field."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"
    CLIENT = "client"

class Vip6SslServerMaxVersionEnum(str, Enum):
    """Allowed values for ssl_server_max_version field."""
    SSL_3_0 = "ssl-3.0"
    TLS_1_0 = "tls-1.0"
    TLS_1_1 = "tls-1.1"
    TLS_1_2 = "tls-1.2"
    TLS_1_3 = "tls-1.3"
    CLIENT = "client"

class Vip6SslClientSessionStateTypeEnum(str, Enum):
    """Allowed values for ssl_client_session_state_type field."""
    DISABLE = "disable"
    TIME = "time"
    COUNT = "count"
    BOTH = "both"

class Vip6SslServerSessionStateTypeEnum(str, Enum):
    """Allowed values for ssl_server_session_state_type field."""
    DISABLE = "disable"
    TIME = "time"
    COUNT = "count"
    BOTH = "both"


# ============================================================================
# Main Model
# ============================================================================

class Vip6Model(BaseModel):
    """
    Pydantic model for firewall/vip6 configuration.
    
    Configure virtual IP for IPv6.
    
    Validation Rules:        - name: max_length=79 pattern=        - id_: min=0 max=65535 pattern=        - uuid: pattern=        - comment: max_length=255 pattern=        - type_: pattern=        - src_filter: pattern=        - src_vip_filter: pattern=        - extip: pattern=        - mappedip: pattern=        - nat_source_vip: pattern=        - ndp_reply: pattern=        - portforward: pattern=        - protocol: pattern=        - extport: pattern=        - mappedport: pattern=        - color: min=0 max=32 pattern=        - ldb_method: pattern=        - server_type: pattern=        - http_redirect: pattern=        - persistence: pattern=        - h2_support: pattern=        - h3_support: pattern=        - quic: pattern=        - nat66: pattern=        - nat64: pattern=        - add_nat64_route: pattern=        - empty_cert_action: pattern=        - user_agent_detect: pattern=        - client_cert: pattern=        - realservers: pattern=        - http_cookie_domain_from_host: pattern=        - http_cookie_domain: max_length=35 pattern=        - http_cookie_path: max_length=35 pattern=        - http_cookie_generation: min=0 max=4294967295 pattern=        - http_cookie_age: min=0 max=525600 pattern=        - http_cookie_share: pattern=        - https_cookie_secure: pattern=        - http_multiplex: pattern=        - http_ip_header: pattern=        - http_ip_header_name: max_length=35 pattern=        - outlook_web_access: pattern=        - weblogic_server: pattern=        - websphere_server: pattern=        - ssl_mode: pattern=        - ssl_certificate: pattern=        - ssl_dh_bits: pattern=        - ssl_algorithm: pattern=        - ssl_cipher_suites: pattern=        - ssl_server_renegotiation: pattern=        - ssl_server_algorithm: pattern=        - ssl_server_cipher_suites: pattern=        - ssl_pfs: pattern=        - ssl_min_version: pattern=        - ssl_max_version: pattern=        - ssl_server_min_version: pattern=        - ssl_server_max_version: pattern=        - ssl_accept_ffdhe_groups: pattern=        - ssl_send_empty_frags: pattern=        - ssl_client_fallback: pattern=        - ssl_client_renegotiation: pattern=        - ssl_client_session_state_type: pattern=        - ssl_client_session_state_timeout: min=1 max=14400 pattern=        - ssl_client_session_state_max: min=1 max=10000 pattern=        - ssl_client_rekey_count: min=200 max=1048576 pattern=        - ssl_server_session_state_type: pattern=        - ssl_server_session_state_timeout: min=1 max=14400 pattern=        - ssl_server_session_state_max: min=1 max=10000 pattern=        - ssl_http_location_conversion: pattern=        - ssl_http_match_host: pattern=        - ssl_hpkp: pattern=        - ssl_hpkp_primary: max_length=79 pattern=        - ssl_hpkp_backup: max_length=79 pattern=        - ssl_hpkp_age: min=60 max=157680000 pattern=        - ssl_hpkp_report_uri: max_length=255 pattern=        - ssl_hpkp_include_subdomains: pattern=        - ssl_hsts: pattern=        - ssl_hsts_age: min=60 max=157680000 pattern=        - ssl_hsts_include_subdomains: pattern=        - monitor: pattern=        - max_embryonic_connections: min=0 max=100000 pattern=        - embedded_ipv4_address: pattern=        - ipv4_mappedip: pattern=        - ipv4_mappedport: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=79, default=None, description="Virtual ip6 name.")    
    id_: int | None = Field(ge=0, le=65535, default=0, serialization_alias="id", description="Custom defined ID.")    
    uuid: str | None = Field(default="00000000-0000-0000-0000-000000000000", description="Universally Unique Identifier (UUID; automatically assigned but can be manually reset).")    
    comment: str | None = Field(max_length=255, default=None, description="Comment.")    
    type_: Literal["static-nat", "server-load-balance", "access-proxy"] | None = Field(default="static-nat", serialization_alias="type", description="Configure a static NAT server load balance VIP or access proxy.")    
    src_filter: list[Vip6SrcFilter] = Field(default_factory=list, description="Source IP6 filter (x:x:x:x:x:x:x:x/x). Separate addresses with spaces.")    
    src_vip_filter: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable use of 'src-filter' to match destinations for the reverse SNAT rule.")    
    extip: str = Field(description="IPv6 address or address range on the external interface that you want to map to an address or address range on the destination network.")    
    mappedip: str = Field(description="Mapped IPv6 address range in the format startIP-endIP.")    
    nat_source_vip: Literal["disable", "enable"] | None = Field(default="disable", description="Enable to perform SNAT on traffic from mappedip to the extip for all egress interfaces.")    
    ndp_reply: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable this FortiGate unit's ability to respond to NDP requests for this virtual IP address (default = enable).")    
    portforward: Literal["disable", "enable"] | None = Field(default="disable", description="Enable port forwarding.")    
    protocol: Literal["tcp", "udp", "sctp"] | None = Field(default="tcp", description="Protocol to use when forwarding packets.")    
    extport: str = Field(description="Incoming port number range that you want to map to a port number range on the destination network.")    
    mappedport: str | None = Field(default=None, description="Port number range on the destination network to which the external port number range is mapped.")    
    color: int | None = Field(ge=0, le=32, default=0, description="Color of icon on the GUI.")    
    ldb_method: Vip6LdbMethodEnum | None = Field(default=Vip6LdbMethodEnum.STATIC, description="Method used to distribute sessions to real servers.")    
    server_type: Vip6ServerTypeEnum = Field(description="Protocol to be load balanced by the virtual server (also called the server load balance virtual IP).")    
    http_redirect: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable redirection of HTTP to HTTPS.")    
    persistence: Literal["none", "http-cookie", "ssl-session-id"] | None = Field(default="none", description="Configure how to make sure that clients connect to the same server every time they make a request that is part of the same session.")    
    h2_support: Literal["enable", "disable"] = Field(default="enable", description="Enable/disable HTTP2 support (default = enable).")    
    h3_support: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable HTTP3/QUIC support (default = disable).")    
    quic: Vip6Quic | None = Field(default=None, description="QUIC setting.")    
    nat66: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable DNAT66.")    
    nat64: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable DNAT64.")    
    add_nat64_route: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable adding NAT64 route.")    
    empty_cert_action: Literal["accept", "block", "accept-unmanageable"] | None = Field(default="block", description="Action for an empty client certificate.")    
    user_agent_detect: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable detecting device type by HTTP user-agent if no client certificate is provided.")    
    client_cert: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable requesting client certificate.")    
    realservers: list[Vip6Realservers] = Field(default_factory=list, description="Select the real servers that this server load balancing VIP will distribute traffic to.")    
    http_cookie_domain_from_host: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable use of HTTP cookie domain from host field in HTTP.")    
    http_cookie_domain: str | None = Field(max_length=35, default=None, description="Domain that HTTP cookie persistence should apply to.")    
    http_cookie_path: str | None = Field(max_length=35, default=None, description="Limit HTTP cookie persistence to the specified path.")    
    http_cookie_generation: int | None = Field(ge=0, le=4294967295, default=0, description="Generation of HTTP cookie to be accepted. Changing invalidates all existing cookies.")    
    http_cookie_age: int | None = Field(ge=0, le=525600, default=60, description="Time in minutes that client web browsers should keep a cookie. Default is 60 minutes. 0 = no time limit.")    
    http_cookie_share: Literal["disable", "same-ip"] | None = Field(default="same-ip", description="Control sharing of cookies across virtual servers. Use of same-ip means a cookie from one virtual server can be used by another. Disable stops cookie sharing.")    
    https_cookie_secure: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable verification that inserted HTTPS cookies are secure.")    
    http_multiplex: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable HTTP multiplexing.")    
    http_ip_header: Literal["enable", "disable"] | None = Field(default="disable", description="For HTTP multiplexing, enable to add the original client IP address in the X-Forwarded-For HTTP header.")    
    http_ip_header_name: str | None = Field(max_length=35, default=None, description="For HTTP multiplexing, enter a custom HTTPS header name. The original client IP address is added to this header. If empty, X-Forwarded-For is used.")    
    outlook_web_access: Literal["disable", "enable"] | None = Field(default="disable", description="Enable to add the Front-End-Https header for Microsoft Outlook Web Access.")    
    weblogic_server: Literal["disable", "enable"] | None = Field(default="disable", description="Enable to add an HTTP header to indicate SSL offloading for a WebLogic server.")    
    websphere_server: Literal["disable", "enable"] | None = Field(default="disable", description="Enable to add an HTTP header to indicate SSL offloading for a WebSphere server.")    
    ssl_mode: Literal["half", "full"] | None = Field(default="half", description="Apply SSL offloading between the client and the FortiGate (half) or from the client to the FortiGate and from the FortiGate to the server (full).")    
    ssl_certificate: list[Vip6SslCertificate] = Field(description="Name of the certificate to use for SSL handshake.")    
    ssl_dh_bits: Vip6SslDhBitsEnum | None = Field(default=Vip6SslDhBitsEnum.V_2048, description="Number of bits to use in the Diffie-Hellman exchange for RSA encryption of SSL sessions.")    
    ssl_algorithm: Vip6SslAlgorithmEnum | None = Field(default=Vip6SslAlgorithmEnum.HIGH, description="Permitted encryption algorithms for SSL sessions according to encryption strength.")    
    ssl_cipher_suites: list[Vip6SslCipherSuites] = Field(default_factory=list, description="SSL/TLS cipher suites acceptable from a client, ordered by priority.")    
    ssl_server_renegotiation: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable secure renegotiation to comply with RFC 5746.")    
    ssl_server_algorithm: Vip6SslServerAlgorithmEnum | None = Field(default=Vip6SslServerAlgorithmEnum.CLIENT, description="Permitted encryption algorithms for the server side of SSL full mode sessions according to encryption strength.")    
    ssl_server_cipher_suites: list[Vip6SslServerCipherSuites] = Field(default_factory=list, description="SSL/TLS cipher suites to offer to a server, ordered by priority.")    
    ssl_pfs: Literal["require", "deny", "allow"] | None = Field(default="require", description="Select the cipher suites that can be used for SSL perfect forward secrecy (PFS). Applies to both client and server sessions.")    
    ssl_min_version: Vip6SslMinVersionEnum | None = Field(default=Vip6SslMinVersionEnum.TLS_1_1, description="Lowest SSL/TLS version acceptable from a client.")    
    ssl_max_version: Vip6SslMaxVersionEnum | None = Field(default=Vip6SslMaxVersionEnum.TLS_1_3, description="Highest SSL/TLS version acceptable from a client.")    
    ssl_server_min_version: Vip6SslServerMinVersionEnum | None = Field(default=Vip6SslServerMinVersionEnum.CLIENT, description="Lowest SSL/TLS version acceptable from a server. Use the client setting by default.")    
    ssl_server_max_version: Vip6SslServerMaxVersionEnum | None = Field(default=Vip6SslServerMaxVersionEnum.CLIENT, description="Highest SSL/TLS version acceptable from a server. Use the client setting by default.")    
    ssl_accept_ffdhe_groups: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable FFDHE cipher suite for SSL key exchange.")    
    ssl_send_empty_frags: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable sending empty fragments to avoid CBC IV attacks (SSL 3.0 & TLS 1.0 only). May need to be disabled for compatibility with older systems.")    
    ssl_client_fallback: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable support for preventing Downgrade Attacks on client connections (RFC 7507).")    
    ssl_client_renegotiation: Literal["allow", "deny", "secure"] | None = Field(default="secure", description="Allow, deny, or require secure renegotiation of client sessions to comply with RFC 5746.")    
    ssl_client_session_state_type: Vip6SslClientSessionStateTypeEnum | None = Field(default=Vip6SslClientSessionStateTypeEnum.BOTH, description="How to expire SSL sessions for the segment of the SSL connection between the client and the FortiGate.")    
    ssl_client_session_state_timeout: int | None = Field(ge=1, le=14400, default=30, description="Number of minutes to keep client to FortiGate SSL session state.")    
    ssl_client_session_state_max: int | None = Field(ge=1, le=10000, default=1000, description="Maximum number of client to FortiGate SSL session states to keep.")    
    ssl_client_rekey_count: int | None = Field(ge=200, le=1048576, default=0, description="Maximum length of data in MB before triggering a client rekey (0 = disable).")    
    ssl_server_session_state_type: Vip6SslServerSessionStateTypeEnum | None = Field(default=Vip6SslServerSessionStateTypeEnum.BOTH, description="How to expire SSL sessions for the segment of the SSL connection between the server and the FortiGate.")    
    ssl_server_session_state_timeout: int | None = Field(ge=1, le=14400, default=60, description="Number of minutes to keep FortiGate to Server SSL session state.")    
    ssl_server_session_state_max: int | None = Field(ge=1, le=10000, default=100, description="Maximum number of FortiGate to Server SSL session states to keep.")    
    ssl_http_location_conversion: Literal["enable", "disable"] | None = Field(default="disable", description="Enable to replace HTTP with HTTPS in the reply's Location HTTP header field.")    
    ssl_http_match_host: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable HTTP host matching for location conversion.")    
    ssl_hpkp: Literal["disable", "enable", "report-only"] | None = Field(default="disable", description="Enable/disable including HPKP header in response.")    
    ssl_hpkp_primary: str | None = Field(max_length=79, default=None, description="Certificate to generate primary HPKP pin from.")  # datasource: ['vpn.certificate.local.name', 'vpn.certificate.ca.name']    
    ssl_hpkp_backup: str | None = Field(max_length=79, default=None, description="Certificate to generate backup HPKP pin from.")  # datasource: ['vpn.certificate.local.name', 'vpn.certificate.ca.name']    
    ssl_hpkp_age: int | None = Field(ge=60, le=157680000, default=5184000, description="Number of minutes the web browser should keep HPKP.")    
    ssl_hpkp_report_uri: str | None = Field(max_length=255, default=None, description="URL to report HPKP violations to.")    
    ssl_hpkp_include_subdomains: Literal["disable", "enable"] | None = Field(default="disable", description="Indicate that HPKP header applies to all subdomains.")    
    ssl_hsts: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable including HSTS header in response.")    
    ssl_hsts_age: int | None = Field(ge=60, le=157680000, default=5184000, description="Number of seconds the client should honor the HSTS setting.")    
    ssl_hsts_include_subdomains: Literal["disable", "enable"] | None = Field(default="disable", description="Indicate that HSTS header applies to all subdomains.")    
    monitor: list[Vip6Monitor] = Field(default_factory=list, description="Name of the health check monitor to use when polling to determine a virtual server's connectivity status.")    
    max_embryonic_connections: int | None = Field(ge=0, le=100000, default=1000, description="Maximum number of incomplete connections.")    
    embedded_ipv4_address: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable use of the lower 32 bits of the external IPv6 address as mapped IPv4 address.")    
    ipv4_mappedip: str | None = Field(default=None, description="Range of mapped IP addresses. Specify the start IP address followed by a space and the end IP address.")    
    ipv4_mappedport: str | None = Field(default=None, description="IPv4 port number range on the destination network to which the external port number range is mapped.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    @field_validator('ssl_hpkp_primary')
    @classmethod
    def validate_ssl_hpkp_primary(cls, v: Any) -> Any:
        """
        Validate ssl_hpkp_primary field.
        
        Datasource: ['vpn.certificate.local.name', 'vpn.certificate.ca.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('ssl_hpkp_backup')
    @classmethod
    def validate_ssl_hpkp_backup(cls, v: Any) -> Any:
        """
        Validate ssl_hpkp_backup field.
        
        Datasource: ['vpn.certificate.local.name', 'vpn.certificate.ca.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "Vip6Model":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)
    # ========================================================================
    # Datasource Validation Methods
    # ========================================================================    
    async def validate_ssl_certificate_references(self, client: Any) -> list[str]:
        """
        Validate ssl_certificate references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - vpn/certificate/local        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = Vip6Model(
            ...     ssl_certificate=[{"name": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_ssl_certificate_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.firewall.vip6.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "ssl_certificate", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("name")
            else:
                value = getattr(item, "name", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.vpn.certificate.local.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Ssl-Certificate '{value}' not found in "
                    "vpn/certificate/local"
                )        
        return errors    
    async def validate_ssl_hpkp_primary_references(self, client: Any) -> list[str]:
        """
        Validate ssl_hpkp_primary references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - vpn/certificate/local        - vpn/certificate/ca        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = Vip6Model(
            ...     ssl_hpkp_primary="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_ssl_hpkp_primary_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.firewall.vip6.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "ssl_hpkp_primary", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.vpn.certificate.local.exists(value):
            found = True
        elif await client.api.cmdb.vpn.certificate.ca.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Ssl-Hpkp-Primary '{value}' not found in "
                "vpn/certificate/local or vpn/certificate/ca"
            )        
        return errors    
    async def validate_ssl_hpkp_backup_references(self, client: Any) -> list[str]:
        """
        Validate ssl_hpkp_backup references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - vpn/certificate/local        - vpn/certificate/ca        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = Vip6Model(
            ...     ssl_hpkp_backup="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_ssl_hpkp_backup_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.firewall.vip6.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "ssl_hpkp_backup", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.vpn.certificate.local.exists(value):
            found = True
        elif await client.api.cmdb.vpn.certificate.ca.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Ssl-Hpkp-Backup '{value}' not found in "
                "vpn/certificate/local or vpn/certificate/ca"
            )        
        return errors    
    async def validate_monitor_references(self, client: Any) -> list[str]:
        """
        Validate monitor references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - firewall/ldb-monitor        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = Vip6Model(
            ...     monitor=[{"name": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_monitor_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.firewall.vip6.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "monitor", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("name")
            else:
                value = getattr(item, "name", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.firewall.ldb_monitor.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Monitor '{value}' not found in "
                    "firewall/ldb-monitor"
                )        
        return errors    
    async def validate_all_references(self, client: Any) -> list[str]:
        """
        Validate ALL datasource references in this model.
        
        Convenience method that runs all validate_*_references() methods
        and aggregates the results.
        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of all validation errors found
            
        Example:
            >>> errors = await policy.validate_all_references(fgt._client)
            >>> if errors:
            ...     for error in errors:
            ...         print(f"  - {error}")
        """
        all_errors = []
        
        errors = await self.validate_ssl_certificate_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_ssl_hpkp_primary_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_ssl_hpkp_backup_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_monitor_references(client)
        all_errors.extend(errors)        
        return all_errors

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "Vip6Model",    "Vip6SrcFilter",    "Vip6Quic",    "Vip6Realservers",    "Vip6Realservers.Monitor",    "Vip6SslCertificate",    "Vip6SslCipherSuites",    "Vip6SslServerCipherSuites",    "Vip6Monitor",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:23:59.992924Z
# ============================================================================